@@ -209,11 +209,16 @@ games_conf_get_accel_map_path (GamesConf *conf,
   GamesConfPrivate *priv = conf->priv;
   char *game_name, *conf_dir;
   char *conf_file = NULL;
+  const char *override;
 
   game_name = g_ascii_strdown (priv->game_name, -1);
 
 #ifdef HAVE_GNOME
-  conf_dir = g_build_filename (g_get_home_dir (), ".gnome2", "accels", NULL);
+  override = g_getenv ("GNOME22_USER_DIR");
+  if (override)
+    conf_dir = g_build_filename (override, "accels", NULL);
+  else
+    conf_dir = g_build_filename (g_get_home_dir (), ".gnome2", "accels", NULL);
 #else
   conf_dir = g_build_filename (g_get_user_config_dir (), "gnome-games", NULL);
 #endif
@@ -1288,7 +1293,7 @@ games_conf_add_window (GtkWindow *window,
   gboolean maximised, fullscreen;
 
   g_return_if_fail (GTK_IS_WINDOW (window));
-  g_return_if_fail (!GTK_WIDGET_REALIZED (window));
+  g_return_if_fail (!gtk_widget_get_realized (GTK_WIDGET (window)));
 
   state = g_slice_new0 (WindowState);
 
